==> qore-oracle-module-3.2.tar.bz2: qore-oracle-module-3.2/docs/oracle/html/navtreedata.js <==
var NAVTREE =
[
  [ "Qore oracle Module", "index.html", [
    [ "Introduction to the oracle Module", "index.html#oracleintro", null ],
    [ "Driver Options", "index.html#ora_options", [
      [ "Number Options", "index.html#number_options", null ]
    ] ],
    [ "Binding and Types", "index.html#bindings_and_types", [
      [ "Time Zone Support", "index.html#timezone", null ]
    ] ],
    [ "Selects With Duplicated Columns", "index.html#select_with_dup_col", [
      [ "Binding by Value", "index.html#binding_by_value", null ],
      [ "Binding by Placeholder", "index.html#binding_by_placeholder", null ],
      [ "Default Oracle to Qore Mappings", "index.html#default_oracle_to_qore_mapping", null ],
      [ "Oracle Array Binds", "index.html#oracle_array_bind", null ],
      [ "CHAR and VARCHAR2 to Qore String", "index.html#string_sizes", [
        [ "Direct Access to Tables/Views", "index.html#string_sizes_tabs", null ],
        [ "PL/SQL Wrappers", "index.html#string_sizes_plsql", null ]
      ] ]
    ] ],
    [ "Named Types (Objects)", "index.html#named_types", null ],
    [ "Oracle Advanced Queueing (AQ)", "index.html#aq", null ],
    [ "Known Issues", "index.html#ora_known_issues", [
      [ "Named Types Known Issues", "index.html#named_types_known_issues", null ],
      [ "Advaned Queueing Known Issues", "index.html#aq_known_issues", null ]
    ] ],
    [ "Release Notes", "index.html#ora_releasenotes", [
      [ "oracle Driver Version 3.2", "index.html#oracle32", null ],
      [ "oracle Driver Version 3.1", "index.html#oracle31", null ],
      [ "oracle Driver Version 3.0", "index.html#oracle30", null ],
      [ "oracle Driver Version 2.2.1", "index.html#oracle221", null ],
      [ "oracle Driver Version 2.2", "index.html#oracle22", null ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", null, [
      [ "Namespace List", "namespaces.html", "namespaces" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
".html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-oracle-module-3.3.tar.bz2: qore-oracle-module-3.3/docs/oracle/html/navtreedata.js <==
var NAVTREE =
[
  [ "Qore oracle Module", "index.html", [
    [ "Introduction to the oracle Module", "index.html#oracleintro", null ],
    [ "Driver Options", "index.html#ora_options", [
      [ "Number Options", "index.html#number_options", null ]
    ] ],
    [ "Binding and Types", "index.html#bindings_and_types", [
      [ "Time Zone Support", "index.html#timezone", null ]
    ] ],
    [ "Selects With Duplicated Columns", "index.html#select_with_dup_col", [
      [ "Binding by Value", "index.html#binding_by_value", null ],
      [ "Binding by Placeholder", "index.html#binding_by_placeholder", null ],
      [ "Default Oracle to Qore Mappings", "index.html#default_oracle_to_qore_mapping", null ],
      [ "Oracle Array Binds", "index.html#oracle_array_bind", null ],
      [ "CHAR and VARCHAR2 to Qore String", "index.html#string_sizes", [
        [ "Direct Access to Tables/Views", "index.html#string_sizes_tabs", null ],
        [ "PL/SQL Wrappers", "index.html#string_sizes_plsql", null ]
      ] ]
    ] ],
    [ "Named Types (Objects)", "index.html#named_types", null ],
    [ "Oracle Advanced Queueing (AQ)", "index.html#aq", null ],
    [ "Known Issues", "index.html#ora_known_issues", [
      [ "Named Types Known Issues", "index.html#named_types_known_issues", null ],
      [ "Advaned Queueing Known Issues", "index.html#aq_known_issues", null ],
      [ "Issues on Darwin/macOS", "index.html#darwin_issues", null ]
    ] ],
    [ "Release Notes", "index.html#ora_releasenotes", [
      [ "oracle Driver Version 3.3", "index.html#oracle33", null ],
      [ "oracle Driver Version 3.2.1", "index.html#oracle321", null ],
      [ "oracle Driver Version 3.2", "index.html#oracle32", null ],
      [ "oracle Driver Version 3.1", "index.html#oracle31", null ],
      [ "oracle Driver Version 3.0", "index.html#oracle30", null ],
      [ "oracle Driver Version 2.2.1", "index.html#oracle221", null ],
      [ "oracle Driver Version 2.2", "index.html#oracle22", null ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", null, [
      [ "Namespace List", "namespaces.html", "namespaces" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
".html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
